==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d5/deb/town__gui_8cpp.js <==
var town__gui_8cpp =
[
    [ "TownAuthorityWindow", "da/d34/structTownAuthorityWindow.html", "da/d34/structTownAuthorityWindow" ],
    [ "TownViewWindow", "d0/dca/structTownViewWindow.html", "d0/dca/structTownViewWindow" ],
    [ "TownDirectoryWindow", "de/d28/structTownDirectoryWindow.html", "de/d28/structTownDirectoryWindow" ],
    [ "FoundTownWindow", "d1/d55/structFoundTownWindow.html", "d1/d55/structFoundTownWindow" ],
    [ "GUITownList", "d5/deb/town__gui_8cpp.html#ae9a344572cd54afabfc28b3f2fa1312c", null ],
    [ "CcFoundRandomTown", "d5/deb/town__gui_8cpp.html#ac8a474ad35431556bb1c8ba26bb17117", null ],
    [ "CcFoundTown", "d5/deb/town__gui_8cpp.html#a61fe8e2ee3c180b5802687f478948a2c", null ],
    [ "ShowFoundTownWindow", "d5/deb/town__gui_8cpp.html#a5ad009f6f309079cb2d7174c7f14c3f5", null ],
    [ "ShowTownAuthorityWindow", "d5/deb/town__gui_8cpp.html#a73094d1bee1dddab56a4de503d0aa0f3", null ],
    [ "ShowTownDirectory", "d5/deb/town__gui_8cpp.html#a35b65b04eb22c054543e5a813169f29e", null ],
    [ "ShowTownViewWindow", "d5/deb/town__gui_8cpp.html#a7fa05100148d062259fe641fdfbdd5a8", null ],
    [ "_found_town_desc", "d5/deb/town__gui_8cpp.html#ae29a52f87705dc7ffc29193bac4cae0a", null ],
    [ "_nested_found_town_widgets", "d5/deb/town__gui_8cpp.html#a3e375d8673da07d8fea636f1dc6651d0", null ],
    [ "_nested_town_authority_widgets", "d5/deb/town__gui_8cpp.html#ad178864cf2919a1ed68dd14f023120a3", null ],
    [ "_nested_town_directory_widgets", "d5/deb/town__gui_8cpp.html#a666f290d2c2f1d7b8e34a6822d2fc9ab", null ],
    [ "_nested_town_editor_view_widgets", "d5/deb/town__gui_8cpp.html#a719c0c65b6441466c309061cb1f07883", null ],
    [ "_nested_town_game_view_widgets", "d5/deb/town__gui_8cpp.html#a5598ea220df574f6fc45c1ad3d174b45", null ],
    [ "_town_authority_desc", "d5/deb/town__gui_8cpp.html#a6b7d5ec5d47560100634621e8058f348", null ],
    [ "_town_directory_desc", "d5/deb/town__gui_8cpp.html#ae2b52190475dd8825092f14105331561", null ],
    [ "_town_editor_view_desc", "d5/deb/town__gui_8cpp.html#a8e0c9e7c1a98241ec70776571cdc9650", null ],
    [ "_town_game_view_desc", "d5/deb/town__gui_8cpp.html#a39f1a5b47ee5cda39a8d59da3cc7dd79", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d5/deb/town__gui_8cpp.js <==
var town__gui_8cpp =
[
    [ "TownAuthorityWindow", "da/d34/structTownAuthorityWindow.html", "da/d34/structTownAuthorityWindow" ],
    [ "TownViewWindow", "d0/dca/structTownViewWindow.html", "d0/dca/structTownViewWindow" ],
    [ "TownDirectoryWindow", "de/d28/structTownDirectoryWindow.html", "de/d28/structTownDirectoryWindow" ],
    [ "FoundTownWindow", "d1/d55/structFoundTownWindow.html", "d1/d55/structFoundTownWindow" ],
    [ "GUITownList", "d5/deb/town__gui_8cpp.html#ae9a344572cd54afabfc28b3f2fa1312c", null ],
    [ "CcFoundRandomTown", "d5/deb/town__gui_8cpp.html#ab63884179ebe5fdaab7466fe47e9e655", null ],
    [ "CcFoundTown", "d5/deb/town__gui_8cpp.html#abbb5ba4e7ecf7c5a6bbf29f6205c221b", null ],
    [ "InitializeTownGui", "d5/deb/town__gui_8cpp.html#ac1b471d19011eee7bec3126e941eeec5", null ],
    [ "ShowFoundTownWindow", "d5/deb/town__gui_8cpp.html#a5ad009f6f309079cb2d7174c7f14c3f5", null ],
    [ "ShowTownAuthorityWindow", "d5/deb/town__gui_8cpp.html#a73094d1bee1dddab56a4de503d0aa0f3", null ],
    [ "ShowTownDirectory", "d5/deb/town__gui_8cpp.html#a35b65b04eb22c054543e5a813169f29e", null ],
    [ "ShowTownViewWindow", "d5/deb/town__gui_8cpp.html#a7fa05100148d062259fe641fdfbdd5a8", null ],
    [ "_found_town_desc", "d5/deb/town__gui_8cpp.html#ae29a52f87705dc7ffc29193bac4cae0a", null ],
    [ "_nested_found_town_widgets", "d5/deb/town__gui_8cpp.html#a3e375d8673da07d8fea636f1dc6651d0", null ],
    [ "_nested_town_authority_widgets", "d5/deb/town__gui_8cpp.html#ad178864cf2919a1ed68dd14f023120a3", null ],
    [ "_nested_town_directory_widgets", "d5/deb/town__gui_8cpp.html#a666f290d2c2f1d7b8e34a6822d2fc9ab", null ],
    [ "_nested_town_editor_view_widgets", "d5/deb/town__gui_8cpp.html#a719c0c65b6441466c309061cb1f07883", null ],
    [ "_nested_town_game_view_widgets", "d5/deb/town__gui_8cpp.html#a5598ea220df574f6fc45c1ad3d174b45", null ],
    [ "_town_authority_desc", "d5/deb/town__gui_8cpp.html#a6b7d5ec5d47560100634621e8058f348", null ],
    [ "_town_directory_desc", "d5/deb/town__gui_8cpp.html#ae2b52190475dd8825092f14105331561", null ],
    [ "_town_editor_view_desc", "d5/deb/town__gui_8cpp.html#a8e0c9e7c1a98241ec70776571cdc9650", null ],
    [ "_town_game_view_desc", "d5/deb/town__gui_8cpp.html#a39f1a5b47ee5cda39a8d59da3cc7dd79", null ],
    [ "Kdtree_TownXYFunc", "d5/deb/town__gui_8cpp.html#a97164edce7efcf9d8e7b490678b485c0", null ]
];
